from _typeshed import Incomplete

import _win32typing

def HrInstallService() -> None: ...
def HrInstallMailboxAgent() -> None: ...
def HrCreateMailboxAgentProfile(serviceName: str, profile: str) -> None: ...
def HrCreateGatewayProfile(serviceName: str, profile: str) -> None: ...
def HrMailboxAgentExists(server: str, siteDN: str, rdn: str) -> None: ...
def HrAdminProgramExists() -> None: ...
def HrRemoveMailboxAgent(server: str, siteDN: str, rdn: str) -> None: ...
def HrRemoveProfile(profile: str) -> None: ...
def HrEnumOrganizations(rootDN: str, server: str) -> list[str]: ...
def HrEnumSites(server: str, organizationDN: str) -> list[str]: ...
def HrEnumContainers(server: str, siteDN: str, fSubtree) -> list[str]: ...
def HrEnumSiteAdmins(server: str, siteDN: str) -> list[str]: ...
def HrGetServiceAccountName(serviceName: str, serviceName1: str) -> str: ...
def HrCreateDirEntryIdEx(addrBook: _win32typing.PyIAddrBook, distinguishedName: str) -> str: ...
def HrCreateProfileName(profPrefix: str) -> str: ...
def HrFindExchangeGlobalAddresslist(addrBook: _win32typing.PyIAddrBook) -> str: ...
def HrGetExchangeStatus(server: str) -> tuple[Incomplete, Incomplete]: ...
def HrGetMailboxDN(session) -> str: ...
def HrGetServerDN(session) -> str: ...
def HrMAPIFindDefaultMsgStore(session: _win32typing.PyIMAPISession) -> str: ...
def HrMAPIFindFolder(folder: _win32typing.PyIMAPIFolder, name: str) -> str: ...
def HrMAPIFindFolderEx(msgStore: _win32typing.PyIMsgStore, sepString: str, path: str) -> str: ...
def HrMAPIFindIPMSubtree(msgStore: _win32typing.PyIMsgStore) -> str: ...
def HrMAPIFindInbox(msgStore: _win32typing.PyIMsgStore) -> str: ...
def HrMAPIFindStore(session: _win32typing.PyIMAPISession, name: str) -> _win32typing.PyIMsgStore: ...
def HrMAPIFindSubfolderEx(rootFolder: _win32typing.PyIMAPIFolder, sep: str, name: str) -> _win32typing.PyIMsgStore: ...
def HrMAPIOpenFolderEx(msgStore: _win32typing.PyIMsgStore, sep: str, name: str) -> _win32typing.PyIMAPIFolder: ...
def HrMAPISetPropBoolean(obj: _win32typing.PyIMAPIProp, tag) -> None: ...
def HrMAPISetPropLong(obj: _win32typing.PyIMAPIProp, tag) -> None: ...
def HrMailboxLogoff(inbox: _win32typing.PyIMsgStore) -> None: ...
def HrMailboxLogon(
    session: _win32typing.PyIMAPISession, msgStore: _win32typing.PyIMsgStore, msgStoreDN: str, mailboxDN: str
) -> _win32typing.PyIMsgStore: ...
def HrOpenExchangePrivateStore(session: _win32typing.PyIMAPISession) -> _win32typing.PyIMsgStore: ...
def HrOpenExchangePublicFolders(store: _win32typing.PyIMsgStore) -> _win32typing.PyIMAPIFolder: ...
def HrOpenExchangePublicStore(session: _win32typing.PyIMAPISession) -> _win32typing.PyIMsgStore: ...
def HrOpenSessionObject(session: _win32typing.PyIMAPISession) -> _win32typing.PyIMAPIProp: ...
def HrOpenSiteContainer(session: _win32typing.PyIMAPISession) -> _win32typing.PyIMAPIProp: ...
def HrOpenSiteContainerAddressing(session: _win32typing.PyIMAPISession) -> _win32typing.PyIMAPIProp: ...
