from _typeshed import Incomplete

from win32.lib.pywintypes import error as error

def GetExpandedName(Source) -> str: ...
def Close(handle) -> None: ...
def Copy(hSrc, hDest): ...
def Init(handle) -> None: ...
def OpenFile(fileName: str, action) -> tuple[Incomplete, Incomplete]: ...
